﻿using System.Xml.Linq;
using Stimulsoft.Base;
using Stimulsoft.Report;
using Stimulsoft.Report.Dictionary;
using Stimulsoft.Report.Export;

static class Program
{
    private const string _licenseKey = "REDACTED";

    static async Task Main(string[] args)
    {
        Console.WriteLine(StiVersion.Version);
        Console.WriteLine(StiVersion.VersionInfo);

        await CreateReport();

        Console.WriteLine("Done!");
    }

    private static async Task CreateReport()
    {
        StiLicense.Key = _licenseKey;
        StiOptions.Export.Pdf.CreatorString = "Stimulsoft";

        StiFontCollection.AddFontFile(@"C:\Windows\Fonts\calibri.ttf");

        var template = await File.ReadAllBytesAsync("Report.xml");
        var data = XDocument.Parse(await File.ReadAllTextAsync("Data.xml"));
        var report = new StiReport();

        report.Load(template);
        LoadData(report, data.Root);
        report.CalculationMode = StiCalculationMode.Interpretation;
        await report.RenderAsync();

        using var stream = new MemoryStream();
        await report.ExportDocumentAsync(StiExportFormat.Pdf, stream, new StiPdfExportSettings
        {
            ImageCompressionMethod = StiPdfImageCompressionMethod.Flate,
            ImageResolutionMode = StiImageResolutionMode.Auto
        });

        stream.Position = 0;
        await using var fileStream = new FileStream("Output.pdf", FileMode.Create, FileAccess.Write);
        stream.WriteTo(fileStream);
    }


    private static void LoadData(StiReport report, XElement xmlData)
    {
        foreach (StiDataSource reportDataSource in report.DataSources)
        {
            if (reportDataSource is StiVirtualSource)
            {
                continue;
            }

            reportDataSource.Dictionary.Databases.Clear();

            if (xmlData != null)
            {
                report.RegData(reportDataSource.Name, xmlData);
            }
        }
    }
}